@@ -3,7 +3,7 @@
 sub new {
   my $class = shift;
 
-  $self = { wordlexer => WordLexer->new, };
+  $self = {}; ###wordlexer => WordLexer->new, };
 
   bless $self, $class;
 }
