@@ -8,12 +8,13 @@ sub new {
   bless $self, $class;
 }
 
-sub scan {
+sub scanLine {
   my $self = shift;
 
+  $self->{printer}->printPrompt;
   my $line = readline;
   
-  ### FIXME
+  return $line;
 }
 
 1;
